"""Module containing classes that represent various aspects of
music."""

from counter import *

class PlayTime:
    # by Sara Sprenkle

    """A class that represents the playing time of music in days,
    hours, minutes, and seconds."""
    
    def __init__(self, days=0, hours=0, minutes=0, seconds=0):
        """Construct a PlayTime object.  days, hours, minutes, and
        seconds are integers.  By default, they're all 0. """
        self.seconds = Counter(0,59)
        self.seconds.setValue(seconds)
        self.minutes = Counter(0,59)
        self.minutes.setValue(minutes)
        self.hours = Counter(0,23)
        self.hours.setValue(hours)
        self.days = 0

    def __str__(self):
        rep = ""
        if self.days > 1:
            rep += "%d days " % self.days
        elif self.days == 1:
            rep += "1 day "
        hours = self.hours.getValue()
        mins = self.minutes.getValue()
        secs = self.seconds.getValue()
        rep += ("%02d:%02d:%02d" % (hours, mins, secs))
        return rep

    def getMinutes(self):
        "Returns the number of minutes in the PlayTime"
        return self.minutes.getValue()

    def getSeconds(self):
        "Returns the number of seconds in the PlayTime"
        return self.seconds.getValue()

    def getHours(self):
        "Returns the number of hours in the PlayTime"
        return self.hours.getValue()

    def getDays(self):
        "Returns the number of days in the PlayTime"
        return self.days

    def addPlayTime(self, playtime):
        """Adds the PlayTime object playtime to this PlayTime object."""
        return self.add(playtime.getDays(), playtime.getHours(), playtime.getMinutes(), playtime.getSeconds())

    def add(self, days, hours, minutes, seconds):
        "Adds the days, hours, minutes and seconds to this Playtime object"
        # increment each part
        numWraps1 = self.seconds.increment(seconds)
        numWraps2 = self.minutes.increment(minutes)
        numWraps3 = self.hours.increment(hours)
        self.days += days
        # handle the "carries"
        if numWraps1 > 0:
            numWraps2 += self.minutes.increment(numWraps1)
        if numWraps2 > 0:
            numWraps3 += self.hours.increment(numWraps2)
        if numWraps3 > 0:
            self.days += numWraps3

def testPlayTime():
    pt = PlayTime()
    print pt
    
    pt.add(0,0,2,30)
    print pt
    
    #test minute wrap
    pt.add(0,0,2,30)
    print pt
    
    pt.addPlayTime(pt)
    print pt
    
    # test hour wrap
    print "Test hour wrap.."
    pt.add(0,0,50,0)
    print pt
    # test minute wrap
    pt.addPlayTime(pt)
    print pt
    
    # test day wrap
    pt.add(0, 22, 0, 1)
    print pt
    pt.addPlayTime(pt)
    print pt
    
    pt2 = PlayTime(0, 23, 59, 59)
    print pt2
    print "Testing rollover..."
    pt2.add(0,0,0,1)
    print pt2


# Only for use during testing
#testPlayTime()
