class Counter:

    # Modified from in-class example.
    
    """Class that represents a Counter object.  Counter has a low and a high value and
    wraps back around from high to low when appropriate.""" 

    def __init__(self, low, high):
        """Create a new Counter object with specified low and high
        integer values."""
        self.low = low
        self.high = high
        self.value = low

    def __str__(self):
        result = "Value: " + str(self.value)
        result += " Low: " + str(self.low)
        result += " High: " + str(self.high)
        return result

    def increment(self, amount=1):
        """ increment the counter, wrapping around to low again, if necessary.
        Default amount is 1.
        Returns number of times had to wrap around. """
        num_wraps = 0
        for x in xrange(amount):
            if self.value < self.high:
                self.value += 1
            else:
                self.value = self.low
                num_wraps += 1
        return num_wraps

    def decrement(self, amount=1):
        """ decrement the counter, wrapping around to high again, if necessary.
        Default amount is 1.
        Returns number of times had to wrap around. """
        num_wraps = 0
        for x in xrange(amount):
            if self.value > self.low:
                self.value -= 1
            else:
                self.value = self.high
                num_wraps += 1
        return num_wraps

    def setValue(self, value):
        """ Sets the counter's value, only if low <= value <= high.  Otherwise,
        prints an error message."""

        if value >= self.low and value <= self.high:
            self.value = value
        else:
            print "ERROR: value must be within range", self.low, "-", \
                  self.high

    def getValue(self):
        "Returns the Counter's current value as an integer."
        return self.value

    def getLow(self):
        "Returns the Counter's low value as an integer."
        return self.low

    def getHigh(self):
        "Returns the Counter's high value as an integer."
        return self.high

    def testCounter():
        c = Counter(5,10)
        print c
        c.increment()
        print c
        c.increment(3)
        print "Current value:", c.getValue()
        c.increment(4)
        print c
